[−][src]Module crystal_engine::event
Re-exported module of winit, with some additional structs that are useful
Structs
| DeviceId | Identifier of an input device. |
| KeyboardInput | Describes a keyboard input event. |
| ModifiersState | Represents the current state of the keyboard modifiers |
| PhysicalPosition | A position represented in physical pixels. |
| Touch | Represents a touch event |
Enums
| DeviceEvent | Represents raw hardware events that are not associated with any particular window. |
| ElementState | Describes the input state of a key. |
| Event | Describes a generic event. |
| Force | Describes the force of a touch event |
| MouseButton | Describes a button of a mouse controller. |
| MouseScrollDelta | Describes a difference in the mouse scroll wheel state. |
| StartCause | Describes the reason the event loop is resuming. |
| TouchPhase | Describes touch-screen input state. |
| VirtualKeyCode | Symbolic name for a keyboard key. |
| WindowEvent | Describes an event from a |
Type Definitions
| AxisId | Identifier for a specific analog axis on some device. |
| ButtonId | Identifier for a specific button on some device. |
| ScanCode | Hardware-dependent keyboard scan code. |