[−][src]Struct crystal_engine::PointLight
A pointlight in the world.
Note: Not implemented yet
For more information, see the amazing tutorial at https://learnopengl.com/Lighting/Colors
Fields
position: Vector3<f32>The position of the light in the world.
color: LightColorThe color of the light in the world.
attenuation: PointLightAttenuationThe attenuation of the light, or how much the light decays over a distance.
PointLightAttenuation implements Default so you can take a good initial value, or you
can tune this until the end of time.